.. :changelog:

History
-------

0.1.3 (2013-07-29)
++++++++++++++++++

* Tests against serving of image files working in all places

0.1.2 (2013-07-28)
++++++++++++++++++

* Added tests against serving of static files
* Mild cleanup

0.1.1 (2013-07-27)
++++++++++++++++++

* Added six and werkzueg as dependencies to deal with Python 3 compat issues.
* Fixed a number of subtle Python 3 problems
* Removed last traces of Kid usage from the project.

0.1.0 (2013-07-27)
++++++++++++++++++

* Frustation
* Inception
* First release on PyPI